<?php

namespace Database\Seeders;

use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;
use App\Models\Template;

class AiTemplateSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $template = [
            [
                'template_name' => 'description',
                'prompt' => "Generate a descriptive response for a given ##title##. The response should be detailed, engaging, and informative, providing relevant information and capturing the reader's interest",
                'module' => 'account',
                'field_json' => '{"field":[{"label":"Asset name","placeholder":"HR may provide some devices ","field_type":"text_box","field_name":"title"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "Generate a lead subject line for a marketing campaign targeting potential customers for a software development company specializing in web and mobile applications.",
                'module' => 'lead',
                'field_json' => '{"field":[{"label":"Description","placeholder":"e.g.","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "Generate a short note summarizing the key points discussed during a lead ##name## call. The purpose of the note is to capture important details and action items discussed with the ##name## lead. Please structure the note in a concise and organized manner.",
                'module' => 'lead',
                'field_json' => '{"field":[{"label":"Lead name","placeholder":"e.g. create description for lead user ","field_type":"textarea","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "Write a long creative product description for: ##title## \n\nTarget audience is: ##audience## \n\nUse this description: ##description## \n\nTone of generated text must be:\n ##tone_language## \n\n",
                'module' => 'product',
                'field_json' => '{"field":[{"label":"Product name","placeholder":"e.g. VR, Honda","field_type":"text_box","field_name":"title"},{"label":"Audience","placeholder":"e.g. Women, Aliens","field_type":"text_box","field_name":"audience"},{"label":"Product Description","placeholder":"e.g. VR is an innovative device that can allow you to be part of virtual world","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "Generate a list of Zoom meeting topics for ##description## metting. The purpose of the meeting is to  ##description##. Structure the topics to ensure a productive discussion.",
                'module' => 'meeting',
                'field_json' => '{"field":[{"label":"Meeting description ","placeholder":"e.g.Remote Collaboration","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate contract subject for this contract description ##description##",
                'module' => 'contract',
                'field_json' => '{"field":[{"label":"Proposal Description","placeholder":"e.g.Terms and Conditions","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'notes',
                'prompt' => "generate contract description for this contract subject ##subject##",
                'module' => 'contract',
                'field_json' => '{"field":[{"label":"Contract Subject","placeholder":"e.g.Legal Protection,Terms and Conditions","field_type":"textarea","field_name":"subject"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate contract description for this contract subject ##subject##",
                'module' => 'contract show',
                'field_json' => '{"field":[{"label":"Contract Subject","placeholder":"e.g.Legal Protection,Terms and Conditions","field_type":"textarea","field_name":"subject"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "Generate a description based on a given document name:##name##. The document name: ##name## represents a specific file or document, and you need a descriptive summary or overview of its contents. Please provide a clear and concise description that captures the main points, purpose, or key information contained within the document. Aim to create a brief but informative description that gives the reader an understanding of what they can expect when accessing or reviewing the document.",
                'module' => 'document',
                'field_json' => '{"field":[{"label":"Document name","placeholder":"","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "give 10 catchy only name of Offer or discount Coupon for : ##keywords##",
                'module' => 'coupon',
                'field_json' => '{"field":[{"label":"Seed words","placeholder":"e.g.coupon will provide you with a discount on your selected plan","field_type":"text_box","field_name":"keywords"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "please suggest subscription plan  name  for this  :  ##description##  for my business",
                'module' => 'plan',
                'field_json' => '{"field":[{"label":"What is your plan about?","placeholder":"e.g. Describe your plan details ","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "please suggest subscription plan  description  for this  :  ##title##:  for my business",
                'module' => 'plan',
                'field_json' => '{"field":[{"label":"What is your plan title?","placeholder":"e.g. Pro Resller,Exclusive Access","field_type":"text_box","field_name":"title"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'content',
                'prompt' => "generate email template for ##type##",
                'module' => 'email template',
                'field_json' => '{"field":[{"label":"Email Type","placeholder":"e.g. new user,new client","field_type":"text_box","field_name":"type"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'content',
                'prompt' => "Generate a      notification message for an ##topic## meeting. Include the date, time, location, and a brief agenda with three key discussion points.",
                'module' => 'notification template',
                'field_json' => '{"field":[{"label":"Notification Message","placeholder":"e.g.brief explanation of the purpose or background of the notification","field_type":"textarea","field_name":"topic"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'meta_keywords',
                'prompt' => "Write SEO meta title for:\n\n ##description## \n\nWebsite name is:\n ##title## \n\nSeed words:\n ##keywords## \n\n",
                'module' => 'seo',
                'field_json' => '{"field":[{"label":"Website Name","placeholder":"e.g. Amazon, Google","field_type":"text_box","field_name":"title"},{"label":"Website Description","placeholder":"e.g. Describe what your website or business do","field_type":"textarea","field_name":"description"},{"label":"Keywords","placeholder":"e.g.  cloud services, databases","field_type":"text_box","field_name":"keywords"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'meta_description',
                'prompt' => "Write SEO meta description for:\n\n ##description## \n\nWebsite name is:\n ##title## \n\nSeed words:\n ##keywords## \n\n",
                'module' => 'seo',
                'field_json' => '{"field":[{"label":"Website Name","placeholder":"e.g. Amazon, Google","field_type":"text_box","field_name":"title"},{"label":"Website Description","placeholder":"e.g. Describe what your website or business do","field_type":"textarea","field_name":"description"},{"label":"Keywords","placeholder":"e.g.  cloud services, databases","field_type":"text_box","field_name":"keywords"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'cookie_title',
                'prompt' => "please suggest me cookie title for this ##description## website which i can use in my website cookie",
                'module' => 'cookie',
                'field_json' => '{"field":[{"label":"Website name or info","placeholder":"e.g. example website ","field_type":"textarea","field_name":"title"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ], [
                'template_name' => 'cookie_description',
                'prompt' => "please suggest me  Cookie description for this cookie title ##title##  which i can use in my website cookie",
                'module' => 'cookie',
                'field_json' => '{"field":[{"label":"Cookie Title ","placeholder":"e.g. example website ","field_type":"text_box","field_name":"title"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'strictly_cookie_title',
                'prompt' => "please suggest me only Strictly Cookie Title for this ##description## website which i can use in my website cookie",
                'module' => 'cookie',
                'field_json' => '{"field":[{"label":"Website name or info","placeholder":"e.g. example website ","field_type":"textarea","field_name":"title"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'strictly_cookie_description',
                'prompt' => "please suggest me Strictly Cookie description for this Strictly cookie title ##title##  which i can use in my website cookie",
                'module' => 'cookie',
                'field_json' => '{"field":[{"label":"Strictly Cookie Title ","placeholder":"e.g. example website ","field_type":"text_box","field_name":"title"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'more_information_description',
                'prompt' => "I need assistance in crafting compelling content for my ##web_name## website's 'Contact Us' page of my website. The page should provide relevant information to users, encourage them to reach out for inquiries, support, and feedback, and reflect the unique value proposition of my business.",
                'module' => 'cookie',
                'field_json' => '{"field":[{"label":"Websit Name","placeholder":"e.g. example website ","field_type":"text_box","field_name":"web_name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "give brief decription of Opportunity detail and cover all point with it's importance for this Opportunity '##name##'",
                'module' => 'opportunities',
                'field_json' => '{"field":[{"label":"Opportunity name  ","placeholder":"e.g.Fashion Fusion Frenzy","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate a tiny and innovative paragraph note which i can attechted with my contant detail please includes seed word : ##keywords##",
                'module' => 'contact',
                'field_json' => '{"field":[{"label":"Seed words","placeholder":"e.g. any time my phone number can be change","field_type":"text_box","field_name":"keywords"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "Create creative product names:  ##description## \n\nSeed words: ##keywords## \n\n",
                'module' => 'product',
                'field_json' => '{"field":[{"label":"Seed words","placeholder":"e.g.  fast, healthy, compact","field_type":"text_box","field_name":"keywords"},{"label":"Product Description","placeholder":"e.g. Provide product details","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate a name of quotation related product saling  using seed  keywords are : ##keywords##",
                'module' => 'quote',
                'field_json' => '{"field":[{"label":"Seed words","placeholder":"e.g.ProQuoteSale","field_type":"text_box","field_name":"keywords"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate a description of  quotation related product saling please note that description should be justify this title  : ##name##",
                'module' => 'quote',
                'field_json' => '{"field":[{"label":"Quote name","placeholder":"e.g.ProQuoteSale","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate a description of  Sales Order related product saling please note that description should be justify this name  : ##name##",
                'module' => 'sales order',
                'field_json' => '{"field":[{"label":"Salesorder name","placeholder":"e.g.SaleMaster","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate a name of Sales Order related saling that saleorder name shoul relate ##name##'",
                'module' => 'sales order',
                'field_json' => '{"field":[{"label":"Quote name","placeholder":"e.g.ProQuoteSale","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate innovative name of Invoice for this Sales Orders:##name##.",
                'module' => 'invoice',
                'field_json' => '{"field":[{"label":"Salesorder name","placeholder":"e.g.SaleMaster","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate a description of invoice related product saling please note that description should be justify this title : ##name##",
                'module' => 'invoice',
                'field_json' => '{"field":[{"label":"Invoice name","placeholder":"e.g.Speedy Sales Impact Invoice","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate a description of invoice  related this item description should be justify this itme name : ##name##",
                'module' => 'invoice item',
                'field_json' => '{"field":[{"label":"Invoice Item name","placeholder":"e.g.name of Invoice item","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate name of case for ##resoan##, case should be relate to product saling business",
                'module' => 'case',
                'field_json' => '{"field":[{"label":"Decribe resoan of case" ,"placeholder":"e.g.name of Invoice item","field_type":"textarea","field_name":"resoan"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate detail & brief description of this perticular case :##name##",
                'module' => 'case',
                'field_json' => '{"field":[{"label":"Case name","placeholder":"e.g.HarmfulGoods Lawsuit","field_type":"text_box","field_name":"name"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "Generate a task name for this decription that specifically related to ##instruction##.",
                'module' => 'task',
                'field_json' => '{"field":[{"label":"Task Instruction","placeholder":"e.g.","field_type":"textarea","field_name":"instruction"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "Generate short task description for a  specifically related  to  this description ##instruction##.",
                'module' => 'task',
                'field_json' => '{"field":[{"label":"Task Instruction","placeholder":"e.g.","field_type":"textarea","field_name":"instruction"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "Write a short and innovative informable description for meeting which about : #    #title## with includes this special information ##description##",
                'module' => 'meeting',
                'field_json' => '{"field":[{"label":"Meeting topic","placeholder":"discuss product sales","field_type":"text_box","field_name":"title"},{"label":"Instruction for meeting ","placeholder":"please come with your presentation","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate call for tile that justify this resoan ##description## for the call ",
                'module' => 'call',
                'field_json' => '{"field":[{"label":"Call Resoan","placeholder":"e.g.Time Management Strategy Call","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate a description of call  related this call description should be justify this call resoan : ##description##",
                'module' => 'call',
                'field_json' => '{"field":[{"label":"Call title","placeholder":"e.g.Time Management Strategy Call","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'comment',
                'prompt' => "generate innovative and descriptive comment of ##title##",
                'module' => 'contract comment',
                'field_json' => '{"field":[{"label":"Contract Name","placeholder":"e.g. product return condition ","field_type":"textarea","field_name":"title"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' => "generate sutiable and valuable name of document please note name should justify the document description  '##description##' .",
                'module' => 'document',
                'field_json' => '{"field":[{"label":"Document Name","placeholder":"e.g. verification file ","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'name',
                'prompt' =>"suggest innovative and valuable campaign name for this : ##description##" ,
                'module' => 'campaign',
                'field_json' => '{"field":[{"label":"Campaign Description","placeholder":"e.g. Where Style Meets Versatility ","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '0',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' =>"generate a description of campaign  related this item description should be justify this campaign name : ##name##" ,
                'module' => 'campaign',
                'field_json' => '{"field":[{"label":"Campaign Name","placeholder":"e.g. Fashion Fusion ","field_type":"textarea","field_name":"description"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'description',
                'prompt' => "generate contract brief description for title '##name##' and cover all point that sutiable to contract title and this contract type is ##type##" ,
                'module' => 'contract desc',
                'field_json' => '{"field":[{"label":"Contract Name","placeholder":"e.g. product return condition ","field_type":"text_box","field_name":"name"},{"label":"Contract Type","placeholder":"e.g. industries ","field_type":"text_box","field_name":"type"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],
            [
                'template_name' => 'note',
                'prompt' => "generate short and valuable note for contract title '##name##'  and this contract type is ##type##",
                'module' => 'contract notes',
                'field_json' => '{"field":[{"label":"Contract Name","placeholder":"e.g. product return condition ","field_type":"textarea","field_name":"name"},{"label":"Contract Type","placeholder":"e.g. industries ","field_type":"text_box","field_name":"type"}]}',
                'is_tone' => '1',
                "created_at" => date('Y-m-d H:i:s'),
                "updated_at" => date('Y-m-d H:i:s'),
            ],

        ];
        Template::insert($template);
    }
}
